package cl.axg.hls_player;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Color;
import android.net.Uri;
import android.os.Handler;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.LinearLayout;

import static com.google.android.exoplayer2.DefaultRenderersFactory.EXTENSION_RENDERER_MODE_PREFER;
import com.google.android.exoplayer2.DefaultRenderersFactory;
import com.google.android.exoplayer2.ExoPlayer;
import com.google.android.exoplayer2.MediaItem;
import com.google.android.exoplayer2.Player;
import com.google.android.exoplayer2.drm.DefaultDrmSessionManagerProvider;
import com.google.android.exoplayer2.ext.rtmp.RtmpDataSource;
import com.google.android.exoplayer2.source.DefaultMediaSourceFactory;
import com.google.android.exoplayer2.source.MediaSource;
import com.google.android.exoplayer2.source.ProgressiveMediaSource;
import com.google.android.exoplayer2.source.dash.DashMediaSource;
import com.google.android.exoplayer2.source.hls.HlsMediaSource;
import com.google.android.exoplayer2.trackselection.DefaultTrackSelector;
import com.google.android.exoplayer2.ui.StyledPlayerView;
import com.google.android.exoplayer2.upstream.DataSource;
import com.google.android.exoplayer2.upstream.DefaultDataSourceFactory;
import com.google.android.exoplayer2.upstream.DefaultHttpDataSource;
import com.google.android.exoplayer2.upstream.HttpDataSource;
import cl.axg.exoplayer.srt_protocolo.SrtLiveStreamDataSourceFactory;


import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.Objects;


public class Common {
    Handler mHandler = new Handler();

    public ExoPlayer initPlayer(Context context, StyledPlayerView playerView){
        playerView.requestFocus();
        if(mHandler!=null)
            mHandler.removeMessages(0);
        DefaultTrackSelector trackSelector = new DefaultTrackSelector(context);
        trackSelector.setParameters(trackSelector.buildUponParameters()
                .setMaxAudioChannelCount(1)
        );
        DefaultRenderersFactory defaultRenderersFactory =
                new DefaultRenderersFactory(context).setExtensionRendererMode(EXTENSION_RENDERER_MODE_PREFER);


        ExoPlayer.Builder playerBuilder =
                new ExoPlayer.Builder(context)
                        .setMediaSourceFactory(createMediaSourceFactory(context));
        ExoPlayer player = playerBuilder.build();
        player.setRepeatMode(Player.REPEAT_MODE_ALL);
        playerView.setPlayer(player);
        return player;
    }

    public void habilitarVentanaEncendida(Window windows){
        windows.addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
    }

    public  void  habilitarPreferenciasReproductor(Window windows){
        windows.getDecorView().setSystemUiVisibility(
                View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                        | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN
                        | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_FULLSCREEN
                        | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY);
    }

    private MediaSource.Factory createMediaSourceFactory(Context context) {
        HttpDataSource.Factory httpDataSource = new DefaultHttpDataSource.Factory();

        DefaultDrmSessionManagerProvider drmSessionManagerProvider =
                new DefaultDrmSessionManagerProvider();
        drmSessionManagerProvider.setDrmHttpDataSourceFactory(
                httpDataSource);
        MediaSource.Factory a = new DefaultMediaSourceFactory(context) ;

        return a ;/* new DefaultMediaSourceFactory(context)
                .setDataSourceFactory(httpDataSource)
                .setDrmSessionManagerProvider(drmSessionManagerProvider) ;*/
    }

    public  MediaSource getMediaSource(Uri uri, Context context) {

        if (uri.toString().toLowerCase().startsWith("rtmp")) {

            RtmpDataSource.Factory rtmpDataSourceFactory = new RtmpDataSource.Factory();
            return new ProgressiveMediaSource.Factory(rtmpDataSourceFactory).createMediaSource(MediaItem.fromUri(uri));

        } else if (uri.toString().toLowerCase().endsWith("m3u8")) {

            DataSource.Factory dataSourceFactory2 = new DefaultHttpDataSource.Factory();
            return new HlsMediaSource.Factory(dataSourceFactory2)
                    .createMediaSource(MediaItem.fromUri(uri));

        } else if (uri.toString().toLowerCase().contains("mpd")) {

            DataSource.Factory dataSourceFactory =
                    new DefaultDataSourceFactory(context, "ua");
            return new DashMediaSource.Factory(dataSourceFactory)
                    .createMediaSource(MediaItem.fromUri(uri));


        } else if (uri.toString().toLowerCase().startsWith("srt")) {

            int port = uri.getPort();
            String url = uri.toString().replace("srt://","").replace(":"+String.valueOf(port),"");

            ProgressiveMediaSource source = new ProgressiveMediaSource.Factory(
                    new SrtLiveStreamDataSourceFactory(
                            url,
                            port,
                            null
                    )
            ).createMediaSource(MediaItem.fromUri(Uri.EMPTY));

            return source;



        }else{
            return null;
        }
    }


}
